python3 -m build
python3 -m twine upload dist/*  --verbose
# python3 -m twine upload --repository-url https://test.pypi.org/legacy/ dist/*  --verbose

# quangnn
# kiJM6jdmyqTLJdD

pip install --upgrade -r requirements.txt

# /home/quang/.local/lib/python3.10/site-packages/tayto/

# apt install -y --allow-downgrades python3.10-venv
